@@ -1 +1,3 @@
+""" Init
+"""
 default_app_config = "core_curate_app.apps.CurateAppConfig"
