@@ -1,9 +1,12 @@
 """ Set of functions to define the common rules for access control across collections
 """
 import logging
+
 from django.contrib.auth.models import User, AnonymousUser
-from core_curate_app.components.curate_data_structure.models import CurateDataStructure
 from core_main_app.access_control.exceptions import AccessControlError
+from core_curate_app.components.curate_data_structure.models import (
+    CurateDataStructure,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -21,11 +24,7 @@ def can_read(func, *args, **kwargs):
     """
     # get the User in the args list
     user = next(
-        (
-            arg
-            for arg in args
-            if isinstance(arg, User) or isinstance(arg, AnonymousUser)
-        ),
+        (arg for arg in args if isinstance(arg, (User, AnonymousUser))),
         None,
     )
 
@@ -38,7 +37,7 @@ def can_read(func, *args, **kwargs):
         return func(*args, **kwargs)
 
     document = func(*args, **kwargs)
-    if type(document) is list:
+    if isinstance(document, list):
         document_list = document
     elif isinstance(document, CurateDataStructure):
         document_list = [document]
@@ -81,11 +80,7 @@ def can_write(func, *args, **kwargs):
 
     """
     user = next(
-        (
-            arg
-            for arg in args
-            if isinstance(arg, User) or isinstance(arg, AnonymousUser)
-        ),
+        (arg for arg in args if isinstance(arg, (User, AnonymousUser))),
         None,
     )
 
@@ -97,7 +92,9 @@ def can_write(func, *args, **kwargs):
     if user.is_superuser:
         return func(*args, **kwargs)
 
-    document = next((arg for arg in args if isinstance(arg, CurateDataStructure)), None)
+    document = next(
+        (arg for arg in args if isinstance(arg, CurateDataStructure)), None
+    )
     if document.user != str(user.id):
         raise AccessControlError(
             "The user doesn't have enough rights to access this document."
