@@ -5,7 +5,9 @@ from rest_framework.serializers import ModelSerializer
 from core_curate_app.components.curate_data_structure import (
     api as curate_data_structure_api,
 )
-from core_curate_app.components.curate_data_structure.models import CurateDataStructure
+from core_curate_app.components.curate_data_structure.models import (
+    CurateDataStructure,
+)
 
 
 class CurateDataStructureAdminSerializer(ModelSerializer):
@@ -30,7 +32,9 @@ class CurateDataStructureAdminSerializer(ModelSerializer):
             if "form_string" in validated_data
             else None,
             data=validated_data["data"] if "data" in validated_data else None,
-            data_structure_element_root=validated_data["data_structure_element_root"]
+            data_structure_element_root=validated_data[
+                "data_structure_element_root"
+            ]
             if "data_structure_element_root" in validated_data
             else None,
         )
