@@ -15,6 +15,13 @@ class FormView(CommonView):
     template = "core_curate_app/user/detail.html"
 
     def get(self, request, *args, **kwargs):
+        """Get the web page of a given form
+
+        Args:
+            request:
+
+        Returns:
+        """
         try:
             # get data structure
             curate_data_structure = _get_curate_data_structure_by_id(
@@ -32,8 +39,14 @@ class FormView(CommonView):
             # Set the assets
             assets = {
                 "js": [
-                    {"path": "core_main_app/common/js/XMLTree.js", "is_raw": False},
-                    {"path": "core_main_app/user/js/data/detail.js", "is_raw": False},
+                    {
+                        "path": "core_main_app/common/js/XMLTree.js",
+                        "is_raw": False,
+                    },
+                    {
+                        "path": "core_main_app/user/js/data/detail.js",
+                        "is_raw": False,
+                    },
                 ],
                 "css": ["core_main_app/common/css/XMLTree.css"],
             }
@@ -41,12 +54,13 @@ class FormView(CommonView):
             # Set the context
             context = {
                 "data_structure": curate_data_structure,
+                "page_title": "View Form",
             }
 
             return self.common_render(
                 request, self.template, assets=assets, context=context
             )
-        except Exception as e:
+        except Exception as exception:
             assets = {
                 "js": [
                     {
@@ -57,8 +71,13 @@ class FormView(CommonView):
             }
             template = "core_main_app/common/commons/error.html"
             if self.administration:
-                template = "core_main_app/admin/commons/errors/errors_wrapper.html"
+                template = (
+                    "core_main_app/admin/commons/errors/errors_wrapper.html"
+                )
 
             return self.common_render(
-                request, template, context={"error": str(e)}, assets=assets
+                request,
+                template,
+                context={"error": str(exception), "page_title": "Error"},
+                assets=assets,
             )
